@@ -27,7 +27,6 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 #include <bonobo/bonobo-main.h>
-#include <gconf/gconf-client.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-stock-icons.h>
@@ -52,12 +51,6 @@ typedef enum {
 	YELP_WINDOW_ACTION_FORWARD
 } YelpHistoryAction;
 
-static GConfEnumStringPair toolbar_styles[] = {
-        { GTK_TOOLBAR_TEXT, "text" },
-        { GTK_TOOLBAR_ICONS, "icons" },
-        { GTK_TOOLBAR_BOTH, "both" },
-	{ GTK_TOOLBAR_BOTH_HORIZ, "both_horiz" }
-};
 
 static void        window_init		          (YelpWindow        *window);
 static void        window_class_init	          (YelpWindowClass   *klass);
@@ -97,6 +90,8 @@ static void        window_new_window_cb           (gpointer           data,
 static void        window_close_window_cb         (gpointer           data,
 						   guint              section,
 						   GtkWidget         *widget);
+static void        window_find_cb                 (gpointer data,     guint section,
+						   GtkWidget         *widget);
 static void        window_history_go_cb           (gpointer           data,
 						   guint              section,
 						   GtkWidget         *widget);
@@ -113,13 +108,6 @@ static GtkWidget * window_create_toolbar          (YelpWindow        *window);
 
 static GdkPixbuf * window_load_icon               (void);
 
-static void        
-window_toolbar_style_changed_cb                   (GConfClient      *client,
-						   guint             cnxn_id,
-						   GConfEntry       *entry,
-						   gpointer          data);
-
-
 
 
 enum {
@@ -141,11 +129,11 @@ struct _YelpWindowPriv {
 
 	GtkWidget      *notebook;
 
-	YelpViewTOC    *toc_view;
-	GtkWidget      *content_view;
-	GtkWidget      *index_view;
+	YelpView       *toc_view;
+	YelpView       *content_view;
+	YelpView       *index_view;
 	
-	GtkWidget      *view_current;
+	GtkWidget      *find_dialog;
 
 	YelpHistory    *history;
 
@@ -158,8 +146,8 @@ struct _YelpWindowPriv {
 static GtkItemFactoryEntry menu_items[] = {
 	{N_("/_File"),              NULL,         0,                  0,                           "<Branch>"},
 	{N_("/File/_New window"),   NULL,         window_new_window_cb,   0,                           "<StockItem>", GTK_STOCK_NEW     },
+/*	{N_("/File/_Find in page..."), NULL,      window_find_cb,         0,                           "<StockItem>", GTK_STOCK_FIND   },*/
 	{N_("/File/_Close window"), NULL,         window_close_window_cb, 0,                           "<StockItem>", GTK_STOCK_CLOSE   },
-/*	{N_("/File/_Quit"),         NULL,         window_exit_cb,         0,                           "<StockItem>", GTK_STOCK_QUIT    }, */
 	{N_("/_Go"),                NULL,         0,                  0,                           "<Branch>"},
 	{N_("/Go/_Back"),           NULL,         window_history_go_cb,   YELP_WINDOW_ACTION_BACK,     "<StockItem>", GTK_STOCK_GO_BACK    },
 	{N_("/Go/_Forward"),        NULL,         window_history_go_cb,   YELP_WINDOW_ACTION_FORWARD,  "<StockItem>", GTK_STOCK_GO_FORWARD },
@@ -188,7 +176,7 @@ yelp_window_get_type (void)
                                 (GInstanceInitFunc) window_init,
                         };
                 
-                window_type = g_type_register_static (GTK_TYPE_WINDOW,
+                window_type = g_type_register_static (GNOME_TYPE_APP,
                                                       "YelpWindow", 
                                                       &window_info, 0);
         }
@@ -208,7 +196,6 @@ window_init (YelpWindow *window)
 	priv->toc_view     = NULL;
 	priv->content_view = NULL;
 	priv->index_view   = NULL;
-	priv->view_current = NULL;
 	
 	priv->history = yelp_history_new ();
 
@@ -255,8 +242,8 @@ window_populate (YelpWindow *window)
 
 	main_box        = gtk_vbox_new (FALSE, 0);
 	
-	gtk_container_add (GTK_CONTAINER (window), main_box);
-
+	gnome_app_set_contents (GNOME_APP (window), main_box);
+	
 	accel_group  = gtk_accel_group_new ();
 	priv->item_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, 
 						   "<main>", accel_group);
@@ -280,13 +267,13 @@ window_populate (YelpWindow *window)
 							 YELP_WINDOW_ACTION_FORWARD);
 	gtk_widget_set_sensitive (menu_item, FALSE);
 
-	gtk_box_pack_start (GTK_BOX (main_box),
-			    gtk_item_factory_get_widget (priv->item_factory,
-							 "<main>"),
-			    FALSE, FALSE, 0);
+	gnome_app_set_menus (GNOME_APP (window), GTK_MENU_BAR (
+				gtk_item_factory_get_widget (priv->item_factory, "<main>")));
 
-	toolbar         = window_create_toolbar (window);
+	toolbar = window_create_toolbar (window);
 
+	gnome_app_set_toolbar (GNOME_APP (window), GTK_TOOLBAR (toolbar));
+			
 	priv->notebook  = gtk_notebook_new ();
 
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->notebook), FALSE);
@@ -299,24 +286,25 @@ window_populate (YelpWindow *window)
 					GTK_POLICY_AUTOMATIC);
 
 	gtk_container_add (GTK_CONTAINER (sw), 
-			   yelp_view_toc_get_widget (priv->toc_view));
+			   priv->toc_view->widget);
 
 	gtk_notebook_insert_page (GTK_NOTEBOOK (priv->notebook),
 				  sw, NULL, PAGE_TOC_VIEW);
 	
 	gtk_notebook_insert_page (GTK_NOTEBOOK (priv->notebook),
-				  priv->content_view,
+				  priv->content_view->widget,
 				  NULL, PAGE_CONTENT_VIEW);
 
 	if (priv->index) {
 		gtk_notebook_insert_page (GTK_NOTEBOOK (priv->notebook),
-					  priv->index_view,
+					  priv->index_view->widget,
 					  NULL, PAGE_INDEX_VIEW);
 	}
 	
-	gtk_box_pack_start (GTK_BOX (main_box), toolbar, FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (main_box), priv->notebook,
 			  TRUE, TRUE, 0);
+
+	gtk_widget_grab_focus (priv->content_view->widget);
 }
 
 static gboolean
@@ -342,7 +330,7 @@ window_handle_uri (YelpWindow *window, YelpURI *uri)
 	else if (yelp_uri_get_type (uri) == YELP_URI_TYPE_TOC) {
 		d(g_print ("[TOC]\n"));
 		
-		yelp_view_toc_open_uri (YELP_VIEW_TOC (priv->toc_view), uri);
+		yelp_view_show_uri (priv->toc_view, uri, NULL);
 
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
 					       PAGE_TOC_VIEW);
@@ -352,9 +340,7 @@ window_handle_uri (YelpWindow *window, YelpURI *uri)
 		d(g_print ("[INDEX]\n"));
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
 					       PAGE_INDEX_VIEW);
-		yelp_view_index_show_uri (YELP_VIEW_INDEX (priv->index_view),
-					  uri, 
-					  &error);
+		yelp_view_show_uri (priv->index_view, uri, &error);
 		handled = TRUE;
 	}
 	else if (yelp_uri_get_type (uri) == YELP_URI_TYPE_MAN ||
@@ -366,9 +352,8 @@ window_handle_uri (YelpWindow *window, YelpURI *uri)
 		d(g_print ("[CONTENT]\n"));
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
 					       PAGE_CONTENT_VIEW);
-		yelp_view_content_show_uri (YELP_VIEW_CONTENT (priv->content_view),
-					    uri,
-					    &error);
+		yelp_view_show_uri (priv->content_view,
+				    uri, &error);
 		handled = TRUE;
 	} else {
 		gnome_url_show (yelp_uri_to_string (uri), &error);
@@ -426,7 +411,7 @@ window_title_changed_cb (gpointer view, const gchar *title, YelpWindow *window)
 	g_return_if_fail (title != NULL);
 	g_return_if_fail (YELP_IS_WINDOW (window));
 	
-	new_title = g_strconcat (_("Help Browser"), ":", title, NULL);
+	new_title = g_strconcat (title, " - ", _("Help Browser"), NULL);
 
 	gtk_window_set_title (GTK_WINDOW (window), new_title);
 
@@ -527,7 +512,7 @@ window_home_button_clicked (GtkWidget *button, YelpWindow *window)
 	uri = yelp_uri_new ("toc:");
 
 	yelp_history_goto (window->priv->history, uri);
-	yelp_view_toc_open_uri (window->priv->toc_view, uri);
+	yelp_view_show_uri (window->priv->toc_view, uri, NULL);
 
 	yelp_uri_unref (uri);
 
@@ -566,6 +551,48 @@ window_close_window_cb (gpointer   data,
 	gtk_widget_destroy (GTK_WIDGET (data));
 }
 
+static void
+window_find_cb (gpointer data, guint section, GtkWidget *widget)
+{
+	YelpWindow     *window = data;
+	YelpWindowPriv *priv;
+	YelpHtml       *html;
+	
+	g_return_if_fail (YELP_IS_WINDOW (data));
+
+	window = YELP_WINDOW (data);
+
+	priv = window->priv;
+
+	/* To get rid of warning for now. */
+	if (0) {
+		window_find_cb (data, section, widget);
+	}
+	
+	switch (gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook))) {
+	case PAGE_TOC_VIEW:
+		html = yelp_view_get_html (priv->toc_view);
+		break;
+	case PAGE_CONTENT_VIEW:
+		html = yelp_view_get_html (priv->content_view);
+		break;
+	case PAGE_INDEX_VIEW:
+		html = yelp_view_get_html (priv->index_view);
+		break;
+	default:
+		g_assert_not_reached ();
+	}
+
+	if (priv->find_dialog) {
+		gtk_window_present (GTK_WINDOW (priv->find_dialog));
+	} else {
+		priv->find_dialog = NULL;
+	}
+
+	/* FIXME: Implement the dialog. */
+	yelp_html_find_next (html);
+}
+
 static void
 window_history_go_cb (gpointer data, guint section, GtkWidget *widget)
 {
@@ -616,40 +643,13 @@ window_create_toolbar (YelpWindow *window)
 	GtkWidget       *toolbar;
 	GtkWidget       *button;
 	GtkWidget       *icon;
-	GConfClient     *conf_client;
-	gchar           *str;
-	GtkToolbarStyle  style = GTK_TOOLBAR_BOTH;
 	
 	g_return_val_if_fail (YELP_IS_WINDOW (window), NULL);
 
 	priv = window->priv;
 
 	toolbar = gtk_toolbar_new ();
-
-	conf_client = gconf_client_get_default ();
 	
-	str = gconf_client_get_string (conf_client, 
-				       "/desktop/gnome/interface/toolbar_style",
-				       NULL);
-
-	if (str) {
-		gconf_string_to_enum (toolbar_styles,
-				      str,
-				      (gint*)&style);
-		g_free (str);
-	}
-
-	gconf_client_notify_add (conf_client, 
-				 "/desktop/gnome/interface/toolbar_style",
-				 window_toolbar_style_changed_cb,
-				 toolbar, NULL, NULL);
-	
-/* 	g_signal_connect(toolbar, "destroy", */
-/* 			 G_CALLBACK(window_remove_notify_cb), */
-/* 			 GINT_TO_POINTER(notify_id)); */
-
-	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), style);
-
 	icon = gtk_image_new_from_stock ("gtk-go-back", 
 					 GTK_ICON_SIZE_LARGE_TOOLBAR);
 
@@ -726,29 +726,6 @@ window_load_icon (void)
 	return pixbuf;
 }
 
-static void
-window_toolbar_style_changed_cb (GConfClient *client,
-				 guint        cnxn_id,
-				 GConfEntry  *entry,
-				 gpointer     data)
-{
-        GtkToolbarStyle  style   = GTK_TOOLBAR_BOTH;
-        GtkToolbar      *toolbar = GTK_TOOLBAR(data);
-	GConfValue      *value;
-
-	value = gconf_entry_get_value (entry);
-
-        /* If no per-app setting use this new global setting */
-        if (value && 
-	    value->type == GCONF_VALUE_STRING &&
-            gconf_value_get_string (value) != NULL) {
-                gconf_string_to_enum(toolbar_styles,
-                                     gconf_value_get_string(value),
-                                     (gint*)&style);
-        }
-
-        gtk_toolbar_set_style(toolbar, style);
-}
 
 GtkWidget *
 yelp_window_new (GNode *doc_tree, GList *index)
@@ -756,7 +733,8 @@ yelp_window_new (GNode *doc_tree, GList *index)
 	YelpWindow     *window;
 	YelpWindowPriv *priv;
 	
-	window = g_object_new (YELP_TYPE_WINDOW, NULL);
+	window = g_object_new (YELP_TYPE_WINDOW, 
+			"app_id", PACKAGE, NULL);
 	priv   = window->priv;
 
 	priv->doc_tree = doc_tree;
